void setup() {
  pinMode(13, OUTPUT); // LED on UNO board
  pinMode(A2, OUTPUT); // GND output to POV
  pinMode(A3, OUTPUT); // connected to RxD/P3.0 on POV
  pinMode(A4, INPUT_PULLUP);  // connected to TxD/P3.1 on POV
  pinMode(A5, OUTPUT); // outputs +5V to power POV
  pinMode(0, INPUT);   // RX input on UNO
  pinMode(1, OUTPUT);  // TX output on UNO
  digitalWrite(A2, LOW); // GND output to POV is low
  digitalWrite(A5, LOW); // +5V output to POV also low (powered off) for now
}

void loop() {
  uint32_t powerOnTillMillis = 0UL; // 
  if (!digitalRead(0)) { // PC is writing to serial port
    digitalWrite(A5, HIGH); // power up POV board
    digitalWrite(13, HIGH); // switch on UNO LED to indicate power is on
    powerOnTillMillis = millis() + 20000UL; // keep it powered up for twenty seconds
  }
  
  while (millis() < powerOnTillMillis) { // for the duration of the powered-up time
    digitalWrite(A3, digitalRead(0)); // copy serial output of PC to POV
    digitalWrite(1, digitalRead(A4)); // copy serial output of POV back to PC
  }
  
  digitalWrite(A5, LOW); // POV board can now be powered down
  if (millis() >= powerOnTillMillis) { // while the POV is not powered up
    digitalWrite(13, millis() % 1000UL > 500UL); // blink the UNO LED on and off to indicate 'ready'
  }
}
